#import <objectbase.h>
#import <objectbase/Swarm.h>
#import <space.h>
#import <activity.h>
#import <collections.h>

@interface ForestModelSwarm : Swarm {
  int speciesNumber ;
  int worldSize ;
  int freqLStrikes;					  
  
  id theForest, theYoungForest, spring, fire, theFireSpace ;
  id speciesList ;

  id modelActions;				  
  id modelSchedule;
}

-populateWithSpecies: aSpecies ;
-(int) getSpeciesNumber ;
-getSpeciesList ;
-(int) getWorldSize ;

-getTheForest ;
-getTheYoungForest ;
-getTheFireSpace ;

+createBegin: (id) aZone;
-createEnd;			
-buildObjects;
-buildActions;
-activateIn: (id) swarmContext;

-fireAtX: (int) theX Y: (int) theY ;
-step ;
@end



















